@@ -128,6 +128,7 @@ static const CoderMapInfo
     { "FTP", "URL" },
     { "FTS", "FITS" },
     { "G3", "FAX" },
+    { "G4", "FAX" },
     { "GIF87", "GIF" },
     { "G", "RAW" },
     { "GRANITE", "MAGICK" },
@@ -249,9 +250,6 @@ static const CoderMapInfo
     { "X3f", "DNG" },
     { "XMP", "META" },
     { "XTRNARRAY", "XTRN" },
-    { "XTRNBLOB", "XTRN" },
-    { "XTRNFILE", "XTRN" },
-    { "XTRNIMAGE", "XTRN" },
     { "XV", "VIFF" },
     { "Y", "RAW" },
     { "YCbCrA", "YCbCr" }
@@ -319,12 +317,6 @@ static void *DestroyCoderNode(void *coder_info)
 static SplayTreeInfo *AcquireCoderCache(const char *filename,
   ExceptionInfo *exception)
 {
-  const StringInfo
-    *option;
-
-  LinkedListInfo
-    *options;
-
   MagickStatusType
     status;
 
@@ -332,25 +324,35 @@ static SplayTreeInfo *AcquireCoderCache(const char *filename,
     i;
 
   SplayTreeInfo
-    *coder_cache;
+    *cache;
 
   /*
     Load external coder map.
   */
-  coder_cache=NewSplayTree(CompareSplayTreeString,RelinquishMagickMemory,
+  cache=NewSplayTree(CompareSplayTreeString,RelinquishMagickMemory,
     DestroyCoderNode);
-  if (coder_cache == (SplayTreeInfo *) NULL)
+  if (cache == (SplayTreeInfo *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   status=MagickTrue;
-  options=GetConfigureOptions(filename,exception);
-  option=(const StringInfo *) GetNextValueInLinkedList(options);
-  while (option != (const StringInfo *) NULL)
+#if !defined(MAGICKCORE_ZERO_CONFIGURATION_SUPPORT)
   {
-    status&=LoadCoderCache(coder_cache,(const char *)
-      GetStringInfoDatum(option),GetStringInfoPath(option),0,exception);
+    const StringInfo
+      *option;
+
+    LinkedListInfo
+      *options;
+
+    options=GetConfigureOptions(filename,exception);
     option=(const StringInfo *) GetNextValueInLinkedList(options);
+    while (option != (const StringInfo *) NULL)
+    {
+      status&=LoadCoderCache(cache,(const char *)
+        GetStringInfoDatum(option),GetStringInfoPath(option),0,exception);
+      option=(const StringInfo *) GetNextValueInLinkedList(options);
+    }
+    options=DestroyConfigureOptions(options);
   }
-  options=DestroyConfigureOptions(options);
+#endif
   /*
     Load built-in coder map.
   */
@@ -376,13 +378,13 @@ static SplayTreeInfo *AcquireCoderCache(const char *filename,
     coder_info->name=(char *) p->name;
     coder_info->exempt=MagickTrue;
     coder_info->signature=MagickSignature;
-    status&=AddValueToSplayTree(coder_cache,ConstantString(coder_info->magick),
+    status&=AddValueToSplayTree(cache,ConstantString(coder_info->magick),
       coder_info);
     if (status == MagickFalse)
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",coder_info->name);
   }
-  return(coder_cache);
+  return(cache);
 }
 
 /*
@@ -785,9 +787,8 @@ MagickExport MagickBooleanType ListCoderInfo(FILE *file,
 %
 %  The format of the LoadCoderCache coder is:
 %
-%      MagickBooleanType LoadCoderCache(SplayTreeInfo *coder_cache,
-%        const char *xml,const char *filename,const size_t depth,
-%        ExceptionInfo *exception)
+%      MagickBooleanType LoadCoderCache(SplayTreeInfo *cache,const char *xml,
+%        const char *filename,const size_t depth,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
@@ -800,9 +801,8 @@ MagickExport MagickBooleanType ListCoderInfo(FILE *file,
 %    o exception: return any errors or warnings in this structure.
 %
 */
-static MagickBooleanType LoadCoderCache(SplayTreeInfo *coder_cache,
-  const char *xml,const char *filename,const size_t depth,
-  ExceptionInfo *exception)
+static MagickBooleanType LoadCoderCache(SplayTreeInfo *cache,const char *xml,
+  const char *filename,const size_t depth,ExceptionInfo *exception)
 {
   char
     keyword[MaxTextExtent],
@@ -892,7 +892,7 @@ static MagickBooleanType LoadCoderCache(SplayTreeInfo *coder_cache,
                   xml=FileToXML(path,~0UL);
                   if (xml != (char *) NULL)
                     {
-                      status&=LoadCoderCache(coder_cache,xml,path,depth+1,
+                      status&=LoadCoderCache(cache,xml,path,depth+1,
                         exception);
                       xml=(char *) RelinquishMagickMemory(xml);
                     }
@@ -919,7 +919,7 @@ static MagickBooleanType LoadCoderCache(SplayTreeInfo *coder_cache,
       continue;
     if (LocaleCompare(keyword,"/>") == 0)
       {
-        status=AddValueToSplayTree(coder_cache,ConstantString(
+        status=AddValueToSplayTree(cache,ConstantString(
           coder_info->magick),coder_info);
         if (status == MagickFalse)
           (void) ThrowMagickException(exception,GetMagickModule(),
