@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -15,8 +15,8 @@
 
   The ImageMagick mime private methods.
 */
-#ifndef _MAGICK_MIME_PRIVATE_H
-#define _MAGICK_MIME_PRIVATE_H
+#ifndef MAGICKCORE_MIME_PRIVATE_H
+#define MAGICKCORE_MIME_PRIVATE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
